@@ -2,18 +2,22 @@
 use strict;
 use warnings;
 
-use Data::Dumper;
 use WebService::YTSearch;
 
 my $key = shift || $ENV{YOUTUBE_API_KEY} || die "Usage: perl $0 12345abcde query num max\n";
-my $id  = shift || 'QhD_OT4wvX0';
+my $id  = shift || 'jjBQTw1e8iU';
 
 my $ws = WebService::YTSearch->new(key => $key);
 
 my $query = { videoId => $id, cmd => 'commentThreads', textFormat => 'plainText' };
 
 my $r = $ws->search(%$query);
-print Dumper $r;
-# for my $item (@{ $r->{items} }) {
-#     print $item->{snippet}{textOriginal}, "\n\n";
-# }
+
+binmode(STDOUT, ':utf8');
+
+for my $item ($r->{items}->@*) {
+    my $x = $item->{snippet}{topLevelComment}{snippet};
+    printf "%s: %s\n\n",
+        $x->{authorDisplayName},
+        $x->{textOriginal};
+}
