@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Search YouTube
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0401';
 
 use strictures 2;
 use Carp qw(croak);
@@ -90,7 +90,7 @@ WebService::YTSearch - Search YouTube
 
 =head1 VERSION
 
-version 0.0400
+version 0.0401
 
 =head1 SYNOPSIS
 
@@ -140,10 +140,10 @@ Fetch the results given the B<arguments>.
 To provide a command other than C<search>, use the C<cmd>
 argument. For example:
 
-  $r = $w->search(%arguments, cmd => 'commentThreads');
+  $r = $w->search(%arguments, cmd => 'commentThreads', videoId => 'abc123xyz');
 
 For all the accepted arguments, please see the YouTube reference
-link below.
+linked below.
 
 =head1 SEE ALSO
 
